package MainWindow;

=pod
=head1 MODULE

MainWindow.pm -the main window for 6reader

This module handles the mechanics of the main window

=cut

sub mainWindow {
  printf STDERR qq(Inside mainWindow\n) if ($::DEBUG);
  $::mw = MainWindow->new();
  $::mw->title("6reader");
  &Menu::mainMenu();

  my $buttonFrame = $::mw->Frame()->pack(-side=>'right', -anchor=>'ne');
  $::canvasFrame = $::mw->Frame()->pack(-expand=>'1', -anchor=>'nw',
					-fill=>'both');

  $::canvas = $::canvasFrame->Scrolled(Canvas)->pack(-expand=>'1', 
						     -fill=>'both');
  $::canvas->configure(-width => $::WIDTH,
		       -height => $::HEIGHT,
		       -relief => 'sunken');

  $buttonFrame->Button(
		       -text=>"First Page",
		       -command=>\&Page::firstPage,
		       -underline=>0
		      )->pack(-fill=>'x');
  $::mw->bind('<KeyPress-f>' => \&Page::firstPage);
  $::mw->bind('<KeyPress-F>' => \&Page::firstPage);

  $buttonFrame->Button(
		       -text=>"Next Page",
		       -command=>\&Page::nextPage,
		       -underline=>0)->pack(-fill=>'x');
  $::mw->bind('<KeyPress-n>' => \&Page::nextPage);
  $::mw->bind('<KeyPress-N>' => \&Page::nextPage);

  $buttonFrame->Button(
		       -text=>"Prev Page",
		       -command=>\&Page::prevPage,
		       -underline=>0
		      )->pack(-fill=>'x');
  $::mw->bind('<KeyPress-p>' => \&Page::prevPage);
  $::mw->bind('<KeyPress-P>' => \&Page::prevPage);

  $buttonFrame->Button(
		       -text=>"Last Page",
		       -command=>\&Page::lastPage,
		       -underline=>0
		      )->pack(-fill=>'x');
  $::mw->bind('<KeyPress-l>' => \&Page::lastPage);
  $::mw->bind('<KeyPress-L>' => \&Page::lastPage);

  $buttonFrame->Button(
		       -text=>"+ Zoom",
		       -command=>\&Page::zoomIn
		      )->pack(-fill=>'x');
  $::mw->bind('<KeyPress-plus>' => \&Page::zoomIn);

  $buttonFrame->Button(
		       -text=>"- Zoom",
		       -command=>\&Page::zoomOut
		      )->pack(-fill=>'x');
  $::mw->bind('<KeyPress-minus>' => \&Page::zoomOut);

  $buttonFrame->Button(
		       -text=>"Quit",
		       -command=>\&Exit::cleanExit,
		       -underline=>0
		      )->pack(-fill=>'x');
  $::mw->bind('<KeyPress-q>' => \&Exit::cleanExit);
  $::mw->bind('<KeyPress-Q>' => \&Exit::cleanExit);

  $::mw->bind('<KeyPress-Left>' => \&Page::moveLeft);
  $::mw->bind('<KeyPress-Right>' => \&Page::moveRight);
  $::mw->bind('<KeyPress-Up>' => \&Page::moveUp);
  $::mw->bind('<KeyPress-Down>' => \&Page::moveDown);

  if ($DEBUG) {
    $::mw->bind('<KeyPress>' => \&print_keysym);

    sub print_keysym {
      my($widget) = @_;
      my $e = $widget->XEvent;    # get event object
      my($keysym_text, $keysym_decimal) = ($e->K, $e->N);
      print "keysym=$keysym_text, numeric=$keysym_decimal\n";
    } # keysm
  } # if
} # mainWindow
;1
